==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/AreaFragmentDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { FragmentBaseDescriptionMetadata } from "./FragmentBaseDescriptionMetadata";
import { AreaFragmentDescription } from "./AreaFragmentDescription";
/**
 * @hidden
 */
export let AreaFragmentDescriptionMetadata = /*@__PURE__*/ (() => {
    class AreaFragmentDescriptionMetadata extends Base {
        static b(a) {
            if (AreaFragmentDescriptionMetadata.a == null) {
                AreaFragmentDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                AreaFragmentDescriptionMetadata.c(AreaFragmentDescriptionMetadata.a);
            }
            if (a.j(AreaFragmentDescriptionMetadata.a)) {
                return;
            }
            a.y(AreaFragmentDescriptionMetadata.a);
        }
        static c(a) {
            FragmentBaseDescriptionMetadata.c(a);
        }
        static d(a) {
            AreaFragmentDescriptionMetadata.b(a);
            a.aa("AreaFragment", () => new AreaFragmentDescription());
            a.z("AreaFragment", AreaFragmentDescriptionMetadata.a);
        }
    }
    AreaFragmentDescriptionMetadata.$t = /*@__PURE__*/ markType(AreaFragmentDescriptionMetadata, 'AreaFragmentDescriptionMetadata');
    AreaFragmentDescriptionMetadata.a = null;
    return AreaFragmentDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/AreaFragmentDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { FragmentBaseDescriptionMetadata } from "./FragmentBaseDescriptionMetadata";
import { AreaFragmentDescription } from "./AreaFragmentDescription";
/**
 * @hidden
 */
export let AreaFragmentDescriptionMetadata = /*@__PURE__*/ (() => {
    class AreaFragmentDescriptionMetadata extends Base {
        static b(a) {
            if (AreaFragmentDescriptionMetadata.a == null) {
                AreaFragmentDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                AreaFragmentDescriptionMetadata.c(AreaFragmentDescriptionMetadata.a);
            }
            if (a.k(AreaFragmentDescriptionMetadata.a)) {
                return;
            }
            a.aa(AreaFragmentDescriptionMetadata.a);
        }
        static c(a) {
            FragmentBaseDescriptionMetadata.c(a);
        }
        static d(a) {
            AreaFragmentDescriptionMetadata.b(a);
            a.ac("AreaFragment", () => new AreaFragmentDescription());
            a.ab("AreaFragment", AreaFragmentDescriptionMetadata.a);
        }
    }
    AreaFragmentDescriptionMetadata.$t = /*@__PURE__*/ markType(AreaFragmentDescriptionMetadata, 'AreaFragmentDescriptionMetadata');
    AreaFragmentDescriptionMetadata.a = null;
    return AreaFragmentDescriptionMetadata;
})();
